@@ -19,6 +19,12 @@ def get_logprobs(model, x, cuda=True):
         y2 = model(x)
     return y2.detach().cpu().numpy()
 
+def get_logprobs_with_batch(model, x, bs=256, cuda=True):
+    return np.vstack([get_logprobs(model, x[i*bs:(i+1)*bs], cuda=cuda) for i in range(math.ceil(len(x)/bs))])
+
+def get_logprobs_with_batch(model, x, bs=256, cuda=True):
+    return np.vstack([get_logprobs(model, x[i*bs:(i+1)*bs], cuda=cuda) for i in range(math.ceil(len(x)/bs))])
+
 def get_probs_from_logprobs(y2):
     return np.exp(np.max(y2, axis=1))
     return np.exp(y2[:,1])
@@ -52,6 +58,14 @@ def norm(x):
     m,s = x.mean(), x.std()
     return (x-m)/s if s>0 else x
 
+def upsample(x, y, k=None, n=None):
+    if n is None and k is None:
+        return x,y
+    k1 = len(np.where(y==1)[0])
+    k0 = k1*k if k is not None else n
+    idx = np.hstack((np.where(y==0)[0][:k0],np.where(y==1)[0]))
+    return x[idx],y[idx]
+
 def frmt_n(n): return f'{n:,}'.replace(',','.')
 
 def show_clsf_stats(y, c, cls, c_szs, c_dist):
