@@ -7,12 +7,19 @@ import matplotlib.pyplot as plt
 import matplotlib as mpl
 import seaborn as sns
 
-
 """
+    Sensitivity (Recall):
+        Proportion of actual positive cases that got predicted as positive
+        TP / (TP+FN) = TP / P
+
+    Specificity (Recall):
+        Proportion of actual negatives, which got predicted as the negative
+        TN / (TN+FP) = TN / N
+
     Precision:
-        A measure of exactness.
-        Out of those predicted positive, how many are actual positive.
-        Good measure when the costs of False Positive is high (ex: email spam).
+        A measure of exactness: out of those predicted positive, how many are actual positive
+        Good measure when the costs of False Positive is high (ex: email spam)
+        TP / (TP+FP) = TP / P2
 
     Recall:
         A measure of a classifiers completeness.
@@ -36,7 +43,6 @@ import seaborn as sns
 
 """
 
-
 def accuracy(y2, y):
     y2 = torch.max(y2, dim=1)[1]
     return (y2==y).float().mean().item()
@@ -45,10 +51,16 @@ def recall(y2, y): # TPR = TP/P (same as sensitivity)
     y2 = torch.max(y2, dim=1)[1]
     tp = torch.mul((y2==y), y.byte()).sum().item()
     p = (y==1).sum().item()
-    r = float(tp) / float(p) if p>0 else 0.0
-    return r
+    # r = float(tp) / float(p) if p>0 else 0.0
+    return tp/p if p>0 else 0.0
 
-def sensitivity(y2, y): # TPR = TP/P (same as recall)
+def precision(y2, y): # TP/(TP+FP)
+    y2 = torch.max(y2, dim=1)[1]
+    tp = torch.mul((y2==y), y.byte()).sum().item()
+    p2 = (y2==1).sum().item()
+    return tp/p2 if p2>0 else 0.0
+
+def sensitivity(y2, y): # (same as recall)
     return recall(y2, y)
 
 def specificity(y2, y): # TNR = TN/N
@@ -57,11 +69,11 @@ def specificity(y2, y): # TNR = TN/N
     n = (y==0).sum().item()
     return tn/n if n>0 else 0.0
 
-def precision(y2, y): # TP/(TP+FP)
-    y2 = torch.max(y2, dim=1)[1]
-    tp = torch.mul((y2==y), y.byte()).sum().item()
-    p = (y2==1).sum().item()
-    return tp/p if p>0 else 0.0
+def balanced_accuracy(y2, y):
+    return (sensitivity(y2,y)+specificity(y2,y))/2
+
+def balanced_accuracy_mult(y2, y):
+    return (sensitivity(y2,y)*specificity(y2,y))/2
 
 def accuracy2(y2, y, threshold=0.5):
     y2 = (y2 > threshold).byte()
