@@ -64,7 +64,8 @@ def Linear(n1, n2, p=None, bn=True, act=default_act):
     if act: net+=[act]
     return nn.Sequential(*net)
 
-def LinearFinal(n1, n2, p=None, act=nn.LogSoftmax(dim=1)): return Linear(n1, n2, p=p, bn=False, act=act)
+def LinearFinal(n1, n2, p=None, act=nn.LogSoftmax(dim=1)):
+    return Linear(n1, n2, p=p, bn=False, act=act)
 
 def Conv2D(n1, n2, ks=3, stride=1, zero_bn=False, act=True):
     bn = nn.BatchNorm2d(n1)
